#[derive(IntoElement)]Expand description
#[derive(IntoElement)] generates an IntoElement impl for any RenderOnce
type, wrapping it in a ViewElement so it can be used as a child.
#[derive(IntoElement)]#[derive(IntoElement)] generates an IntoElement impl for any RenderOnce
type, wrapping it in a ViewElement so it can be used as a child.