pub enum AnchoredFitMode {
SnapToWindow,
SnapToWindowWithMargin(Edges<Pixels>),
SwitchAnchor,
}Expand description
Which algorithm to use when fitting the anchored element to be inside the window.
Variants
SnapToWindow
Snap the anchored element to the window edge.
SnapToWindowWithMargin(Edges<Pixels>)
Snap to window edge and leave some margins.
SwitchAnchor
Switch which corner anchor this anchored element is attached to.