pub enum Decorations {
Server,
Client {
tiling: Tiling,
},
}Expand description
A type to describe how this window is currently configured
Variants
Server
The window is configured to use server side decorations
Client
The window is configured to use client side decorations