pub enum FollowMode {
Normal,
Tail,
}Expand description
Controls whether the list automatically follows new content at the end.
Variants
Normal
Normal scrolling — no automatic following.
Tail
The list should auto-scroll along with the tail, when scrolled to bottom.