pub enum GridTemplateMinSize {
Zero,
MinContent,
MaxContent,
}Expand description
The minimum size of a column or row in a grid layout
Variants
Zero
The column or row size may be 0
MinContent
The column or row size can be determined by the min content
MaxContent
The column or row size can be determined by the max content