pub enum ObjectFit {
Fill,
Contain,
Cover,
ScaleDown,
None,
}Expand description
How to fit the image into the bounds of the element.
Variants
Fill
The image will be stretched to fill the bounds of the element.
Contain
The image will be scaled to fit within the bounds of the element.
Cover
The image will be scaled to cover the bounds of the element.
ScaleDown
The image will be scaled down to fit within the bounds of the element.
None
The image will maintain its original size.
Implementations