pub enum ProgressBarState {
None,
Indeterminate,
Normal(f64),
Error(f64),
Paused(f64),
}Expand description
The state of a taskbar/dock progress bar for a window.
Variants
None
No progress bar is shown.
Indeterminate
An indeterminate progress bar is shown.
Normal(f64)
A normal progress bar with the given fraction (0.0 to 1.0).
Error(f64)
An error progress bar with the given fraction (0.0 to 1.0).
Paused(f64)
A paused progress bar with the given fraction (0.0 to 1.0).