pub enum PromptLevel {
Info,
Warning,
Critical,
}Expand description
What kind of prompt styling to show
Variants
Info
A prompt that is shown when the user should be notified of something
Warning
A prompt that is shown when the user needs to be warned of a potential problem
Critical
A prompt that is shown when a critical problem has occurred