ScrollDelta

Enum ScrollDelta 

pub enum ScrollDelta {
    Pixels(Point<Pixels>),
    Lines(Point<f32>),
}
The scroll delta for a scroll wheel event.

Variants



Pixels(Point<Pixels>)

An exact scroll delta in pixels.



Lines(Point<f32>)

An inexact scroll delta in lines.

Implementations

Source

impl ScrollDelta

pub fn precise(&self) -> bool

Returns true if this is a precise scroll delta in pixels.

pub fn pixel_delta(&self, line_height: Pixels) -> Point<Pixels>

Converts this scroll event into exact pixels.

pub fn coalesce(self, other: ScrollDelta) -> ScrollDelta

Combines two scroll deltas into one. If the signs of the deltas are the same (both positive or both negative), the deltas are added together. If the signs are opposite, the second delta (other) is used, effectively overriding the first delta.