pub enum TemplateColumnMinSize {
Zero,
MinContent,
MaxContent,
}Expand description
The minimum size of a column or row in a grid layout
Variants
Zero
The column size may be 0
MinContent
The column size can be determined by the min content
MaxContent
The column size can be determined by the max content