pub enum TouchPhase {
Started,
Moved,
Ended,
Cancelled,
}Expand description
The phase of a touch motion event. Based on the winit enum of the same name.
Variants
Started
The touch started.
Moved
The touch event is moving.
Ended
The touch phase has ended
Cancelled
The touch was cancelled: the system took it and it will not end normally. Consumers must fully unwind any in-progress interaction, treating the touch as if it never committed.