pub enum WindowBackgroundAppearance {
Opaque,
Transparent,
Blurred,
MicaBackdrop,
MicaAltBackdrop,
}Expand description
The appearance of the background of the window itself, when there is no content or the content is transparent.
Variants
Opaque
Opaque.
This lets the window manager know that content behind this window does not need to be drawn.
Actual color depends on the system and themes should define a fully opaque background color instead.
Transparent
Plain alpha transparency.
Blurred
Transparency, but the contents behind the window are blurred.
Not always supported.
MicaBackdrop
The Mica backdrop material, supported on Windows 11.
MicaAltBackdrop
The Mica Alt backdrop material, supported on Windows 11.