pub enum WindowControlArea {
Drag,
Close,
Max,
Min,
}Expand description
A type of window control area that corresponds to the platform window.
Variants
Drag
An area that allows dragging of the platform window.
Close
An area that allows closing of the platform window.
Max
An area that allows maximizing of the platform window.
Min
An area that allows minimizing of the platform window.