pub struct FunctionReflection<T> {
pub name: &'static str,
pub function: fn(Box<dyn Any>) -> Box<dyn Any>,
pub documentation: Option<&'static str>,
pub _type: PhantomData<T>,
}Expand description
Reification of a function that has the signature fn some_fn(T) -> T. Provides the name,
documentation, and ability to invoke the function.
Fields
name: &'static strThe name of the function
function: fn(Box<dyn Any>) -> Box<dyn Any>The method
documentation: Option<&'static str>Documentation for the function
_type: PhantomData<T>PhantomData for the type of the argument and result
Implementations
Sourceimpl<T: 'static> FunctionReflection<T>
impl<T: 'static> FunctionReflection<T>