pub enum KeyboardInteractivity {
None,
Exclusive,
OnDemand,
}Expand description
Keyboard interactivity mode for the layer_shell surfaces.
Variants
None
No keyboard inputs will be delivered to the surface and it won’t be able to receive keyboard focus.
Exclusive
The surface will receive exclusive keyboard focus as long as it is above the shell surface layer, and no other layer_shell surfaces are above it.
OnDemand
The surface can be focused similarly to a normal window.