Layer

Enum Layer 

pub enum Layer {
    Background,
    Bottom,
    Top,
    Overlay,
}
The layer the surface is rendered on. Multiple surfaces can share a layer, and ordering within a single layer is undefined.

Variants



Background

The background layer, typically used for wallpapers.



Bottom

The bottom layer.



Top

The top layer, typically used for fullscreen windows.



Overlay

The overlay layer, used for surfaces that should always be on top.