pub struct LayerShellOptions {
pub namespace: String,
pub layer: Layer,
pub anchor: Anchor,
pub exclusive_zone: Option<Pixels>,
pub exclusive_edge: Option<Anchor>,
pub margin: Option<(Pixels, Pixels, Pixels, Pixels)>,
pub keyboard_interactivity: KeyboardInteractivity,
}Expand description
Options for creating a layer_shell window.
Fields
namespace: StringThe namespace for the surface, mostly used by compositors to apply rules, can not be changed after the surface is created.
layer: LayerThe layer the surface is rendered on.
anchor: AnchorThe anchor point of the surface.
exclusive_zone: Option<Pixels>Requests that the compositor avoids occluding an area with other surfaces.
exclusive_edge: Option<Anchor>The anchor point of the exclusive zone, will be determined using the anchor if left unspecified.
margin: Option<(Pixels, Pixels, Pixels, Pixels)>Margins between the surface and its anchor point(s). Specified in CSS order: top, right, bottom, left.
keyboard_interactivity: KeyboardInteractivityHow keyboard events should be delivered to the surface.