Module popup

Module popup 

Types for configuring parent-anchored popup windows such as menus, dropdowns and tooltips.

Structs

PopupConstraintAdjustment
How a popup may be adjusted by the platform if the requested placement would put it off-screen. If no flags are set, the popup is placed exactly as requested and may be clipped.
PopupNotSupportedError
Returned when the current platform has no native popup implementation yet.
PopupOptions
Options for a parent-anchored popup window such as a menu, dropdown, context menu or tooltip.

Enums

PopupAnchor
The point of the anchor rectangle that a popup is anchored to.
PopupGravity
The direction in which a popup extends away from its anchor point.