pub enum PopupGravity {
Center,
Top,
Bottom,
Left,
Right,
TopLeft,
BottomLeft,
TopRight,
BottomRight,
}Expand description
The direction in which a popup extends away from its anchor point.
For instance, a gravity of PopupGravity::BottomRight places the popup below and to the
right of the anchor point.
Variants
Center
The popup is centered over the anchor point.
Top
The popup extends upwards from the anchor point.
Bottom
The popup extends downwards from the anchor point.
Left
The popup extends to the left of the anchor point.
Right
The popup extends to the right of the anchor point.
TopLeft
The popup extends up and to the left of the anchor point.
BottomLeft
The popup extends down and to the left of the anchor point.
TopRight
The popup extends up and to the right of the anchor point.
BottomRight
The popup extends down and to the right of the anchor point.