pub struct FrameTiming {
pub window_id: WindowId,
pub dirty_at: Option<Instant>,
pub invalidations: u64,
pub draw_start: Instant,
pub draw_end: Instant,
}Expand description
Timing for a single drawn window frame.
Fields
window_id: WindowIdThe window that was drawn.
dirty_at: Option<Instant>When the frame first became dirty (its first invalidation). None if
frame tracing was not yet enabled when the invalidation occurred.
invalidations: u64Number of invalidations coalesced into this frame.
draw_start: InstantWhen Window::draw started.
draw_end: InstantWhen Window::draw finished.
Implementations
Sourceimpl FrameTiming
impl FrameTiming
Sourcepub fn draw_duration(&self) -> Duration
pub fn draw_duration(&self) -> Duration
Time spent inside Window::draw.
Sourcepub fn dirty_to_draw_duration(&self) -> Option<Duration>
pub fn dirty_to_draw_duration(&self) -> Option<Duration>
Time from the frame’s first invalidation to the end of its draw, if the first invalidation was observed.