FrameTimingCollector

Struct FrameTimingCollector 

pub struct FrameTimingCollector { /* private fields */ }
Drains frame timings recorded after this collector was created, tracking a cursor so each call to Self::collect_unseen returns only new entries.

Implementations

Source

impl FrameTimingCollector

pub fn new() -> Self

Creates a collector that only sees frames recorded from this point on.

pub fn collect_unseen(&mut self) -> Vec<FrameTiming>

Returns frame timings recorded since the previous call (or since the collector was created). If the ring buffer wrapped around since the previous poll, the evicted entries are lost.