Module single_instance

Module single_instance 

Cross-platform single instance enforcement using Unix domain sockets and Windows named mutexes.

Structs

AlreadyRunning
Error returned when another instance of the application is already running.
SingleInstance
A guard that enforces single-instance behavior for an application.

Functions

send_activate_to_existing
Send an activation message to an already-running instance of the application.