pub struct Anchored { /* private fields */ }Expand description
An anchored element that can be used to display UI that will avoid overflowing the window bounds.
Implementations
Sourceimpl Anchored
impl Anchored
Sourcepub fn anchor(self, anchor: Corner) -> Self
pub fn anchor(self, anchor: Corner) -> Self
Sets which corner of the anchored element should be anchored to the current position.
Sourcepub fn position(self, anchor: Point<Pixels>) -> Self
pub fn position(self, anchor: Point<Pixels>) -> Self
Sets the position in window coordinates (otherwise the location the anchored element is rendered is used)
Sourcepub fn offset(self, offset: Point<Pixels>) -> Self
pub fn offset(self, offset: Point<Pixels>) -> Self
Offset the final position by this amount. Useful when you want to anchor to an element but offset from it, such as in PopoverMenu.
Sourcepub fn position_mode(self, mode: AnchoredPositionMode) -> Self
pub fn position_mode(self, mode: AnchoredPositionMode) -> Self
Sets the position mode for this anchored element. Local will have this
interpret its Anchored::position as relative to the parent element.
While Window will have it interpret the position as relative to the window.
Sourcepub fn snap_to_window(self) -> Self
pub fn snap_to_window(self) -> Self
Snap to window edge instead of switching anchor corner when an overflow would occur.
Sourcepub fn snap_to_window_with_margin(self, edges: impl Into<Edges<Pixels>>) -> Self
pub fn snap_to_window_with_margin(self, edges: impl Into<Edges<Pixels>>) -> Self
Snap to window edge and leave some margins.