Animation

Struct Animation 

pub struct Animation {
    pub duration: Duration,
    pub oneshot: bool,
    pub synced: bool,
    pub easing: Rc<dyn Fn(f32) -> f32>,
    pub max_fps: Option<f32>,
}
An animation that can be applied to an element.

Fields

duration: Duration

The amount of time for which this animation should run

oneshot: bool

Whether to repeat this animation when it finishes

synced: bool

Whether to derive the phase from a shared clock. See Animation::repeat_synced.

easing: Rc<dyn Fn(f32) -> f32>

A function that maps normalized time to an animated value. The result may exceed 0..1 for easing functions that overshoot.

max_fps: Option<f32>

The maximum number of times per second this animation re-renders. When None, the animation re-renders on every frame.

Implementations

Source

impl Animation

pub fn new(duration: Duration) -> Self

Create a new animation with the given duration. By default the animation will only run once and will use a linear easing function.

pub fn repeat(self) -> Self

Set the animation to loop when it finishes.

pub fn repeat_synced(self) -> Self

Set the animation to loop when it finishes, phase-locked to a clock shared by the whole App.

pub fn with_easing(self, easing: impl Fn(f32) -> f32 + 'static) -> Self

Sets the easing function used to map normalized time to an animated value.

The output is not clamped, allowing physical easing functions such as springs to overshoot.

pub fn with_max_fps(self, max_fps: f32) -> Self

Limit how often this animation re-renders. Instead of re-rendering on every frame, the animation schedules its next render 1 / max_fps seconds after the current one. Values that are not finite and positive are ignored.