AnimationPhase

Struct AnimationPhase 

pub struct AnimationPhase(pub f32);
A potentially overshooting coordinate within an animation.

Phases are not restricted to 0..1. Multi-stage animations can assign each stage its own coordinate and interpolate over ranges such as 1..=2.

Tuple Fields

0: f32

The unbounded phase coordinate.

Implementations

Source

impl AnimationPhase

pub fn clamp(self, range: RangeInclusive<f32>) -> Self

Restricts this phase to the bounds of a range.

pub fn interpolate<T: Interpolate>(self, from: T, to: T) -> T

Interpolates between values using 0 and 1 as their phase coordinates.

pub fn interpolate_clamped<T: Interpolate>(self, from: T, to: T) -> T

Interpolates between values without extrapolating beyond 0 and 1.

pub fn interpolate_between<T: Interpolate>( self, range: RangeInclusive<f32>, from: T, to: T, ) -> T

Interpolates between values assigned to arbitrary phase coordinates.

pub fn interpolate_between_clamped<T: Interpolate>( self, range: RangeInclusive<f32>, from: T, to: T, ) -> T

Interpolates over arbitrary phase coordinates without extrapolating.