pub struct AnyWeakEntity { /* private fields */ }Expand description
A type erased, weak reference to a entity.
Implementations
Sourceimpl AnyWeakEntity
impl AnyWeakEntity
Sourcepub fn is_upgradable(&self) -> bool
pub fn is_upgradable(&self) -> bool
Check if this weak handle can be upgraded, or if the entity has already been dropped
Sourcepub fn upgrade(&self) -> Option<AnyEntity>
pub fn upgrade(&self) -> Option<AnyEntity>
Upgrade this weak entity reference to a strong reference.
Sourcepub fn new_invalid() -> Self
pub fn new_invalid() -> Self
Creates a weak entity that can never be upgraded.