ClipboardItem

Struct ClipboardItem 

pub struct ClipboardItem {
    pub entries: Vec<ClipboardEntry>,
}
A clipboard item that should be copied to the clipboard

Fields

entries: Vec<ClipboardEntry>

The entries in this clipboard item.

Implementations

Source

impl ClipboardItem

pub fn new_string(text: String) -> Self

Create a new ClipboardItem::String with no associated metadata

pub fn new_string_with_metadata(text: String, metadata: String) -> Self

Create a new ClipboardItem::String with the given text and associated metadata

pub fn new_string_with_json_metadata<T: Serialize>( text: String, metadata: T, ) -> Self

Create a new ClipboardItem::String with the given text and associated metadata

pub fn new_image(image: &Image) -> Self

Create a new ClipboardItem::Image with the given image with no associated metadata

pub fn text(&self) -> Option<String>

Concatenates together all the ClipboardString entries in the item. Returns None if there were no ClipboardString entries.

pub fn metadata(&self) -> Option<&String>

If this item is one ClipboardEntry::String, returns its metadata.

pub fn entries(&self) -> &[ClipboardEntry]

Get the item’s entries

pub fn into_entries(self) -> impl Iterator<Item = ClipboardEntry>

Get owned versions of the item’s entries