pub struct ClipboardString {
pub text: String,
pub metadata: Option<String>,
}Expand description
A clipboard item that should be copied to the clipboard
Fields
text: StringThe text content.
metadata: Option<String>Optional metadata associated with this clipboard string.
Implementations
Sourceimpl ClipboardString
impl ClipboardString
Sourcepub fn with_json_metadata<T: Serialize>(self, metadata: T) -> Self
pub fn with_json_metadata<T: Serialize>(self, metadata: T) -> Self
Return a new clipboard item with the metadata replaced by the given metadata, after serializing it as JSON.
Sourcepub fn metadata_json<T>(&self) -> Option<T>where
T: for<'a> Deserialize<'a>,
pub fn metadata_json<T>(&self) -> Option<T>where
T: for<'a> Deserialize<'a>,
Get the metadata of the clipboard string, formatted as JSON