pub struct ElementClickedState {
pub group: bool,
pub element: bool,
}Expand description
Whether or not the element or a group that contains it is clicked by the mouse.
Fields
group: boolTrue if this element’s group has been clicked, false otherwise
element: boolTrue if this element has been clicked, false otherwise