pub struct FileDragPaths(/* private fields */);Expand description
Paths handed to the platform for a native file drag. Directory metadata is provided by the caller to avoid querying it when the platform drag starts.
Implementations
Sourceimpl FileDragPaths
impl FileDragPaths