pub struct FocusedWindowInfo {
pub app_name: String,
pub window_title: String,
pub bundle_id: Option<String>,
pub pid: Option<u32>,
}Expand description
Information about the currently focused window from any application.
Fields
app_name: StringThe name of the application that owns the focused window.
window_title: StringThe title of the focused window.
bundle_id: Option<String>The bundle identifier of the application (macOS only).
pid: Option<u32>The process ID of the application.