FontMetrics

Struct FontMetrics 

pub struct FontMetrics {
    pub units_per_em: u32,
    pub ascent: f32,
    pub descent: f32,
    pub line_gap: f32,
    pub underline_position: f32,
    pub underline_thickness: f32,
    pub cap_height: f32,
    pub x_height: f32,
    pub bounding_box: Bounds<f32>,
}
A struct for storing font metrics. It is used to define the measurements of a typeface.

Fields

units_per_em: u32

The number of font units that make up the “em square”, a scalable grid for determining the size of a typeface.

ascent: f32

The vertical distance from the baseline of the font to the top of the glyph covers.

descent: f32

The vertical distance from the baseline of the font to the bottom of the glyph covers.

line_gap: f32

The recommended additional space to add between lines of type.

underline_position: f32

The suggested position of the underline.

underline_thickness: f32

The suggested thickness of the underline.

cap_height: f32

The height of a capital letter measured from the baseline of the font.

x_height: f32

The height of a lowercase x.

bounding_box: Bounds<f32>

The outer limits of the area that the font covers. Corresponds to the xMin / xMax / yMin / yMax values in the OpenType head table

Implementations

Source

impl FontMetrics

pub fn ascent(&self, font_size: Pixels) -> Pixels

Returns the vertical distance from the baseline of the font to the top of the glyph covers in pixels.

pub fn descent(&self, font_size: Pixels) -> Pixels

Returns the vertical distance from the baseline of the font to the bottom of the glyph covers in pixels.

pub fn line_gap(&self, font_size: Pixels) -> Pixels

Returns the recommended additional space to add between lines of type in pixels.

pub fn underline_position(&self, font_size: Pixels) -> Pixels

Returns the suggested position of the underline in pixels.

pub fn underline_thickness(&self, font_size: Pixels) -> Pixels

Returns the suggested thickness of the underline in pixels.

pub fn cap_height(&self, font_size: Pixels) -> Pixels

Returns the height of a capital letter measured from the baseline of the font in pixels.

pub fn x_height(&self, font_size: Pixels) -> Pixels

Returns the height of a lowercase x in pixels.

pub fn bounding_box(&self, font_size: Pixels) -> Bounds<Pixels>

Returns the outer limits of the area that the font covers in pixels.