pub struct GestureKinds {
pub tap: bool,
pub long_press: bool,
pub pan: bool,
pub pinch: bool,
}Expand description
The set of gesture kinds that participate in recognition.
Used by PlatformGestures::native_recognizers to declare which gestures
the platform recognizes natively rather than leaving to gpui core’s
portable recognizers.
Fields
tap: boolTap (and multi-tap), surfaced as ClickEvent::Touch.
long_press: boolLong press, surfaced as LongPressEvent.
pan: boolPan/scroll (including fling momentum), surfaced as
ScrollWheelEvents.
pinch: boolPinch to zoom, surfaced as PinchEvents.
Implementations