pub struct GestureTuning {
pub touch_slop: Pixels,
pub multi_tap_interval: Duration,
pub multi_tap_slop: Pixels,
pub long_press_duration: Duration,
pub momentum_decay_per_ms: f32,
pub min_fling_velocity: f32,
}Expand description
Feel constants consumed by gesture recognizers. Provided on a best-effort basis, depending on each platform’s support, defaulting to GPUI’s own (iOS flavored) values
Fields
touch_slop: PixelsDistance a touch may travel before it stops being a potential tap and becomes a pan/drag.
multi_tap_interval: DurationMaximum interval between taps for them to accumulate a tap count.
multi_tap_slop: PixelsMaximum distance between taps for them to accumulate a tap count.
long_press_duration: DurationHow long a touch must remain within Self::touch_slop to be
recognized as a long press.
momentum_decay_per_ms: f32Per-millisecond decay factor applied to scroll momentum after a fling.
(UIScrollView uses 0.998 per millisecond for its normal
deceleration rate.)
min_fling_velocity: f32Minimum release velocity, in pixels per second, required to start scroll momentum.