HeadlessAtlas

Struct HeadlessAtlas 

pub struct HeadlessAtlas(/* private fields */);
A sprite atlas for windows without a GPU. It hands out uniquely identified tiles without uploading any pixels, so glyph, SVG, and image painting can run to completion in tests and headless platforms.