pub struct ItemSize {
pub item: Size<Pixels>,
pub contents: Size<Pixels>,
}Expand description
The size of the item and its contents.
Fields
item: Size<Pixels>The size of the item.
contents: Size<Pixels>The size of the item’s contents, which may be larger than the item itself, if the item was bounded by a parent element.