pub struct KeyBindingMetaIndex(pub u32);Expand description
A unique identifier for retrieval of metadata associated with a key binding. Intended to be used as an index or key into a user-defined store of metadata associated with the binding, such as the source of the binding.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for KeyBindingMetaIndex
impl Clone for KeyBindingMetaIndex
Sourcefn clone(&self) -> KeyBindingMetaIndex
fn clone(&self) -> KeyBindingMetaIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeyBindingMetaIndex
impl Debug for KeyBindingMetaIndex
Sourceimpl Hash for KeyBindingMetaIndex
impl Hash for KeyBindingMetaIndex
Sourceimpl PartialEq for KeyBindingMetaIndex
impl PartialEq for KeyBindingMetaIndex
Sourcefn eq(&self, other: &KeyBindingMetaIndex) -> bool
fn eq(&self, other: &KeyBindingMetaIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for KeyBindingMetaIndex
impl Eq for KeyBindingMetaIndex
impl StructuralPartialEq for KeyBindingMetaIndex