pub struct KeyboardClickEvent {
pub button: KeyboardButton,
pub bounds: Bounds<Pixels>,
}Expand description
A click event that was generated by a keyboard button being pressed and released.
Fields
The keyboard button that was pressed to trigger the click.
bounds: Bounds<Pixels>The bounds of the element that was clicked.