pub struct KeymapVersion(/* private fields */);Expand description
An opaque identifier of which version of the keymap is currently active. The keymap’s version is changed whenever bindings are added or removed.