KeystrokeEvent

Struct KeystrokeEvent 

pub struct KeystrokeEvent {
    pub keystroke: Keystroke,
    pub input_preference: InputPreference,
    pub action: Option<Box<dyn Action>>,
    pub context_stack: Vec<KeyContext>,
}
A keystroke event, and potentially the associated action

Fields

keystroke: Keystroke

The keystroke that occurred

input_preference: InputPreference

Whether this keystroke should prefer character input or key bindings. This is InputPreference::CharacterInput when the platform prefers text for the key (e.g. AltGr on Windows) and the focused input accepts text. Interceptors still receive these keystrokes and can consume them.

If the keystroke is part of a multi-stroke binding, it still waits as pending input even when this is InputPreference::CharacterInput.

action: Option<Box<dyn Action>>

The action that was resolved for the keystroke, if any

context_stack: Vec<KeyContext>

The context stack at the time