pub struct ListOffset {
pub item_ix: usize,
pub offset_in_item: Pixels,
}Expand description
An offset into the list’s items, in terms of the item index and the number of pixels off the top left of the item.
Fields
item_ix: usizeThe index of an item in the list
offset_in_item: PixelsThe number of pixels to offset from the item index.