pub struct ListScrollEvent {
pub visible_range: Range<usize>,
pub count: usize,
pub is_scrolled: bool,
pub is_following_tail: bool,
}Expand description
A scroll event that has been converted to be in terms of the list’s items.
Fields
visible_range: Range<usize>The range of items currently visible in the list, after applying the scroll event.
count: usizeThe number of items that are currently visible in the list, after applying the scroll event.
is_scrolled: boolWhether the list has been scrolled.
is_following_tail: boolWhether the list is currently in follow-tail mode (auto-scrolling to end).