pub struct MissingGlyph { /* private fields */ }Expand description
A grapheme cluster that could not be represented by any available font.
Implementations
Sourceimpl MissingGlyph
impl MissingGlyph
Sourcepub fn new(grapheme: SharedString, font_class: FallbackFontClass) -> Self
pub fn new(grapheme: SharedString, font_class: FallbackFontClass) -> Self
Creates a missing-glyph report.
Sourcepub fn font_class(&self) -> FallbackFontClass
pub fn font_class(&self) -> FallbackFontClass
Returns the spacing behavior required of a fallback font.