pub struct OngoingScroll { /* private fields */ }Expand description
Tracks the dominant axis across the events in a scroll gesture.
Implementations
Sourceimpl OngoingScroll
impl OngoingScroll
Sourcepub fn filter(&mut self, delta: &mut Point<Pixels>, touch_phase: TouchPhase)
pub fn filter(&mut self, delta: &mut Point<Pixels>, touch_phase: TouchPhase)
Filters the given delta to the dominant axis of the current scroll gesture.
Gestures are delimited by their touch phase when available, with a timeout
fallback for platforms that only emit TouchPhase::Moved.