pub struct OwnedOsMenu {
pub name: SharedString,
pub menu_type: SystemMenuType,
}Expand description
OS menus are menus that are recognized by the operating system This allows the operating system to provide specialized items for these menus
Fields
name: SharedStringThe name of the menu
The type of menu