pub struct Path<P: Clone + Debug + Default + PartialEq> {
pub id: PathId,
pub order: DrawOrder,
pub bounds: Bounds<P>,
pub content_mask: ContentMask<P>,
pub vertices: Vec<PathVertex<P>>,
pub color: Background,
/* private fields */
}Expand description
A line made up of a series of vertices and control points.
Fields
id: PathIdorder: DrawOrderbounds: Bounds<P>content_mask: ContentMask<P>vertices: Vec<PathVertex<P>>color: BackgroundImplementations
Sourceimpl Path<Pixels>
impl Path<Pixels>
Sourcepub fn scale(&self, factor: f32) -> Path<ScaledPixels>
pub fn scale(&self, factor: f32) -> Path<ScaledPixels>
Scale this path by the given factor.
Sourcepub fn line_to(&mut self, to: Point<Pixels>)
pub fn line_to(&mut self, to: Point<Pixels>)
Draw a straight line from the current point to the given point.