pub struct PinchEvent {
pub position: Point<Pixels>,
pub delta: f32,
pub modifiers: Modifiers,
pub phase: TouchPhase,
}Expand description
A pinch gesture event from the platform, generated when the user performs a pinch-to-zoom gesture (typically on a trackpad).
Fields
position: Point<Pixels>The position of the pinch center on the window.
delta: f32The zoom delta for this event. Positive values indicate zooming in, negative values indicate zooming out. For example, 0.1 represents a 10% zoom increase.
modifiers: ModifiersThe modifiers that were held down during the pinch gesture.
phase: TouchPhaseThe phase of the pinch gesture.
Methods from Deref<Target = Modifiers>