pub struct RenderGlyphParams {
pub font_id: FontId,
pub glyph_id: GlyphId,
pub font_size: Pixels,
pub subpixel_variant: Point<u8>,
pub scale_factor: f32,
pub is_emoji: bool,
pub subpixel_rendering: bool,
pub dilation: u8,
}Expand description
Parameters for rendering a glyph, used as cache keys for raster bounds.
This struct identifies a specific glyph rendering configuration including font, size, subpixel positioning, and scale factor. It’s used to look up cached raster bounds and sprite atlas entries.
Fields
font_id: FontIdglyph_id: GlyphIdfont_size: Pixelssubpixel_variant: Point<u8>scale_factor: f32is_emoji: boolsubpixel_rendering: booldilation: u8Trait Implementations
Sourceimpl Clone for RenderGlyphParams
impl Clone for RenderGlyphParams
Sourcefn clone(&self) -> RenderGlyphParams
fn clone(&self) -> RenderGlyphParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderGlyphParams
impl Debug for RenderGlyphParams
Sourceimpl From<RenderGlyphParams> for AtlasKey
impl From<RenderGlyphParams> for AtlasKey
Sourcefn from(params: RenderGlyphParams) -> Self
fn from(params: RenderGlyphParams) -> Self
Converts to this type from the input type.
Sourceimpl Hash for RenderGlyphParams
impl Hash for RenderGlyphParams
Sourceimpl PartialEq for RenderGlyphParams
impl PartialEq for RenderGlyphParams
Sourcefn eq(&self, other: &RenderGlyphParams) -> bool
fn eq(&self, other: &RenderGlyphParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RenderGlyphParams
impl StructuralPartialEq for RenderGlyphParams