#[repr(C)]pub struct Rgba {
pub r: f32,
pub g: f32,
pub b: f32,
pub a: f32,
}Expand description
An RGBA color
Fields
r: f32The red component of the color, in the range 0.0 to 1.0
g: f32The green component of the color, in the range 0.0 to 1.0
b: f32The blue component of the color, in the range 0.0 to 1.0
a: f32The alpha component of the color, in the range 0.0 to 1.0
Implementations