StyledText

Struct StyledText 

pub struct StyledText { /* private fields */ }
Renders text with runs of different styles.

Callers are responsible for setting the correct style for each run. For text with a uniform style, you can usually avoid calling this constructor and just pass text directly.

Implementations

Source

impl StyledText

pub fn new(text: impl Into<SharedString>) -> Self

Construct a new styled text element from the given string.

pub fn layout(&self) -> &TextLayout

Get the layout for this element. This can be used to map indices to pixels and vice versa.

pub fn with_default_highlights( self, default_style: &TextStyle, highlights: impl IntoIterator<Item = (Range<usize>, HighlightStyle)>, ) -> Self

Set the styling attributes for the given text, as well as as any ranges of text that have had their style customized.

pub fn with_highlights( self, highlights: impl IntoIterator<Item = (Range<usize>, HighlightStyle)>, ) -> Self

Set the styling attributes for the given text, as well as as any ranges of text that have had their style customized.

pub fn with_font_family_overrides( self, overrides: impl IntoIterator<Item = (Range<usize>, SharedString)>, ) -> Self

Override the font family for specific byte ranges of the text.

This is resolved lazily at layout time, so the overrides are applied on top of the inherited text style from the parent element. Can be combined with with_highlights.

The overrides must be sorted by range start and non-overlapping. Each override range must fall on character boundaries.

pub fn with_runs(self, runs: Vec<TextRun>) -> Self

Set the text runs for this piece of text.