pub struct TextLayout(/* private fields */);Expand description
The Layout for TextElement. This can be used to map indices to pixels and vice versa.
Implementations
Sourceimpl TextLayout
impl TextLayout
Sourcepub fn paint_background(&self, window: &mut Window, cx: &mut App) -> Result<()>
pub fn paint_background(&self, window: &mut Window, cx: &mut App) -> Result<()>
Paints the backgrounds of the text runs without the glyphs, so that callers can paint
content, such as highlights, between the backgrounds and the text. Follow it with
Self::paint_foreground to paint the glyphs.
Sourcepub fn paint_foreground(&self, window: &mut Window, cx: &mut App) -> Result<()>
pub fn paint_foreground(&self, window: &mut Window, cx: &mut App) -> Result<()>
Paints the glyphs and decorations of the text without the run backgrounds.
Sourcepub fn index_for_position(
&self,
position: Point<Pixels>,
) -> Result<usize, usize>
pub fn index_for_position( &self, position: Point<Pixels>, ) -> Result<usize, usize>
Get the byte index into the input of the pixel position.
Sourcepub fn position_for_index(&self, index: usize) -> Option<Point<Pixels>>
pub fn position_for_index(&self, index: usize) -> Option<Point<Pixels>>
Get the pixel position for the given byte index.
Sourcepub fn line_layout_for_index(
&self,
index: usize,
) -> Option<Arc<WrappedLineLayout>>
pub fn line_layout_for_index( &self, index: usize, ) -> Option<Arc<WrappedLineLayout>>
Retrieve the layout for the line containing the given byte index.
Sourcepub fn line_layouts(&self) -> SmallVec<[Arc<WrappedLineLayout>; 1]>
pub fn line_layouts(&self) -> SmallVec<[Arc<WrappedLineLayout>; 1]>
Retrieve all line layouts in source order.
Sourcepub fn line_height(&self) -> Pixels
pub fn line_height(&self) -> Pixels
The line height for this layout.
Sourcepub fn wrapped_text(&self) -> String
pub fn wrapped_text(&self) -> String
The text for this layout (with soft-wraps as newlines)