pub struct TextShadow {
pub color: Hsla,
pub offset: Point<Pixels>,
pub blur_radius: Pixels,
}Expand description
A shadow effect applied to text, rendered by painting glyphs twice.
Fields
color: HslaThe color of the text shadow
offset: Point<Pixels>How far the shadow is offset from the text
blur_radius: PixelsThe blur radius of the shadow (approximated via opacity reduction)