pub struct ToastStack { /* private fields */ }Expand description
A stack of toast notifications that manages display and auto-dismissal.
Create a ToastStack as a GPUI entity and render it as part of your
window’s view tree. Use ToastStack::push to add new toasts.
Implementations
Sourceimpl ToastStack
impl ToastStack
Sourcepub fn with_position(self, position: ToastPosition) -> Self
pub fn with_position(self, position: ToastPosition) -> Self
Set the default position for toasts in this stack.