pub struct TouchDragEvent {
pub phase: TouchPhase,
pub start_position: Point<Pixels>,
pub position: Point<Pixels>,
}Expand description
A direct touch drag claimed by an element before touch input becomes a tap, long press, or scrolling gesture.
Fields
phase: TouchPhaseThe phase of the touch drag.
start_position: Point<Pixels>The position where the touch started.
position: Point<Pixels>The touch’s current position.