pub struct TouchId(pub u64);Expand description
Identifies one touch (finger or stylus contact) for its lifetime, from
TouchPhase::Started through TouchPhase::Ended or
TouchPhase::Cancelled.
The value is opaque and platform-defined; it is only guaranteed to be stable for the duration of the touch and unique among concurrent touches.
Tuple Fields
0: u64Trait Implementations
impl Copy for TouchId
impl Eq for TouchId
Sourceimpl Ord for TouchId
impl Ord for TouchId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for TouchId
impl PartialOrd for TouchId
impl StructuralPartialEq for TouchId