pub struct UTF16Selection {
pub range: Range<usize>,
pub reversed: bool,
}Expand description
A struct representing a selection in a text buffer, in UTF16 characters. This is different from a range because the head may be before the tail.
Fields
range: Range<usize>The range of text in the document this selection corresponds to in UTF16 characters.
reversed: boolWhether the head of this selection is at the start (true), or end (false) of the range