Unbind

Struct Unbind 

pub struct Unbind(pub SharedString);
Action with special handling which unbinds later bindings for the same keystrokes when they dispatch the named action, regardless of that action’s context.

In keymap JSON this is written as:

["zed::Unbind", "editor::NewLine"]

Tuple Fields

0: SharedString