pub struct WindowInsets {
pub safe_area: Edges<Pixels>,
pub ime: Edges<Pixels>,
}Expand description
Regions of a window that are obscured or reserved by the system.
Mobile applications often share space in their window with system-specific geometry, from keyboards to camera notches. In GPUI, all this is abstracted into a single “inset” which should be overlaid on the window’s bounds. It is up to the application develop to determine how to handle these cases.
Fields
safe_area: Edges<Pixels>Regions covered by system UI or hardware: status bar, display
cutouts/notch, home indicator, navigation bars.
(iOS: safeAreaInsets. Android: WindowInsets of types
systemBars() | displayCutout().)
ime: Edges<Pixels>The region covered by the keyboard, when present.
(iOS: derived from keyboardWillShow/frame-change notifications.
Android: WindowInsets.Type.ime().)
Implementations