pub struct WindowParams {
pub bounds: Bounds<Pixels>,
pub titlebar: Option<TitlebarOptions>,
pub kind: WindowKind,
pub is_movable: bool,
pub is_resizable: bool,
pub is_minimizable: bool,
pub focus: bool,
pub show: bool,
pub icon: Option<Arc<RgbaImage>>,
pub display_id: Option<DisplayId>,
pub window_min_size: Option<Size<Pixels>>,
}Expand description
The variables that can be configured when creating a new window
Fields
bounds: Bounds<Pixels>titlebar: Option<TitlebarOptions>The titlebar configuration of the window
kind: WindowKindThe kind of window to create
is_movable: boolWhether the window should be movable by the user
is_resizable: boolWhether the window should be resizable by the user
is_minimizable: boolWhether the window should be minimized by the user
focus: boolshow: boolicon: Option<Arc<RgbaImage>>An image to set as the window icon (x11 only)
display_id: Option<DisplayId>window_min_size: Option<Size<Pixels>>Trait Implementations