pub struct WrapBoundary {
pub run_ix: usize,
pub glyph_ix: usize,
}Expand description
A boundary at which a line was wrapped
Fields
run_ix: usizeThe index in the run just before the line was wrapped
glyph_ix: usizeThe index of the glyph just before the line was wrapped