PlatformGestures

Trait PlatformGestures 

pub trait PlatformGestures {
    // Provided methods
    fn tuning(&self) -> GestureTuning { ... }
    fn native_recognizers(&self) -> GestureKinds { ... }
}
Platform gesture recognition services.

If your mobile platform supports native gesture recognition, use this to share it with GPUI.

Provided Methods

fn tuning(&self) -> GestureTuning

Feel constants for the portable recognizers on this platform.

fn native_recognizers(&self) -> GestureKinds

The gesture kinds this platform recognizes natively.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors