pub trait Prompt: EventEmitter<PromptResponse> + Focusable { }Expand description
A prompt that can be rendered in the window.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait Prompt: EventEmitter<PromptResponse> + Focusable { }A prompt that can be rendered in the window.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".