Types for configuring parent-anchored popup windows such as menus, dropdowns and tooltips.
Structs
- Popup
Constraint Adjustment - How a popup may be adjusted by the platform if the requested placement would put it off-screen. If no flags are set, the popup is placed exactly as requested and may be clipped.
- Popup
NotSupported Error - Returned when the current platform has no native popup implementation yet.
- Popup
Options - Options for a parent-anchored popup window such as a menu, dropdown, context menu or tooltip.
Enums
- Popup
Anchor - The point of the anchor rectangle that a popup is anchored to.
- Popup
Gravity - The direction in which a popup extends away from its anchor point.