Cross-platform single instance enforcement using Unix domain sockets and Windows named mutexes.
Structs
- Already
Running - Error returned when another instance of the application is already running.
- Single
Instance - A guard that enforces single-instance behavior for an application.
Functions
- send_
activate_ to_ existing - Send an activation message to an already-running instance of the application.