pub struct A11ySubtreeBuilder<'a> { /* private fields */ }Expand description
Builder API for synthetic children. See the docs for
Element::a11y_synthetic_children.
Implementations
Sourceimpl<'a> A11ySubtreeBuilder<'a>
impl<'a> A11ySubtreeBuilder<'a>
Sourcepub fn synthetic_node_id(&self, key: impl Hash) -> NodeId
pub fn synthetic_node_id(&self, key: impl Hash) -> NodeId
Derive a NodeId for a synthetic child.
The generated ID is based on the hash of key, as well as the parent’s
ID. This means that keys must be unique within the same
Element::a11y_synthetic_children call, but may be duplicated across
different calls.
Sourcepub fn push_child(&mut self, id: NodeId, node: Node) -> bool
pub fn push_child(&mut self, id: NodeId, node: Node) -> bool
Append a synthetic leaf node as a child of this element’s node.
Returns false if a node with this id is already present in the tree,
in which case the node is discarded.
Sourcepub fn parent_node(&mut self) -> &mut Node
pub fn parent_node(&mut self) -> &mut Node
A mutable reference to the parent node.