#[repr(C)]pub struct ContentMask<P: Clone + Debug + Default + PartialEq> {
pub bounds: Bounds<P>,
}Expand description
Indicates which region of the window is visible. Content falling outside of this mask will not be rendered. Currently, only rectangular content masks are supported, but we give the mask its own type to leave room to support more complex shapes in the future.
Fields
bounds: Bounds<P>The bounds
Implementations
Sourceimpl ContentMask<Pixels>
impl ContentMask<Pixels>
Sourcepub fn scale(&self, factor: f32) -> ContentMask<ScaledPixels>
pub fn scale(&self, factor: f32) -> ContentMask<ScaledPixels>
Scale the content mask’s pixel units by the given scaling factor.