pub struct Entity<T> { /* private fields */ }Expand description
A strong, well-typed reference to a struct which is managed by GPUI
Implementations
Sourceimpl<T: 'static> Entity<T>
impl<T: 'static> Entity<T>
Sourcepub fn downgrade(&self) -> WeakEntity<T>
pub fn downgrade(&self) -> WeakEntity<T>
Downgrade this entity pointer to a non-retaining weak pointer
Sourcepub fn read_with<R, C: AppContext>(
&self,
cx: &C,
f: impl FnOnce(&T, &App) -> R,
) -> R
pub fn read_with<R, C: AppContext>( &self, cx: &C, f: impl FnOnce(&T, &App) -> R, ) -> R
Read the entity referenced by this handle with the given function.
Sourcepub fn update<R, C: AppContext>(
&self,
cx: &mut C,
update: impl FnOnce(&mut T, &mut Context<'_, T>) -> R,
) -> R
pub fn update<R, C: AppContext>( &self, cx: &mut C, update: impl FnOnce(&mut T, &mut Context<'_, T>) -> R, ) -> R
Updates the entity referenced by this handle with the given function.
Sourcepub fn as_mut<'a, C: AppContext>(&self, cx: &'a mut C) -> GpuiBorrow<'a, T>
pub fn as_mut<'a, C: AppContext>(&self, cx: &'a mut C) -> GpuiBorrow<'a, T>
Updates the entity referenced by this handle with the given function.
Sourcepub fn write<C: AppContext>(&self, cx: &mut C, value: T)
pub fn write<C: AppContext>(&self, cx: &mut C, value: T)
Updates the entity referenced by this handle with the given function.
Sourcepub fn update_in<R, C: VisualContext>(
&self,
cx: &mut C,
update: impl FnOnce(&mut T, &mut Window, &mut Context<'_, T>) -> R,
) -> C::Result<R>
pub fn update_in<R, C: VisualContext>( &self, cx: &mut C, update: impl FnOnce(&mut T, &mut Window, &mut Context<'_, T>) -> R, ) -> C::Result<R>
Updates the entity referenced by this handle with the given function if the referenced entity still exists, within a visual context that has a window. Returns an error if the window has been closed.
Sourceimpl<T: Render> Entity<T>
impl<T: Render> Entity<T>
Sourcepub fn cached(self, style: StyleRefinement) -> ViewElement<Entity<T>>
pub fn cached(self, style: StyleRefinement) -> ViewElement<Entity<T>>
Embed this entity as a cached [ViewElement] laid out at style.
The rendered subtree is reused until the entity is notified (or the
cached bounds / text style change). Caching requires a definite size:
a cached view is laid out from style and is not measured from its
contents. Use [ViewElement::new] (or .child(entity)) for the
uncached case.
Methods from Deref<Target = AnyEntity>
Sourcepub fn entity_type(&self) -> TypeId
pub fn entity_type(&self) -> TypeId
Returns the TypeId associated with this entity.
Sourcepub fn downgrade(&self) -> AnyWeakEntity
pub fn downgrade(&self) -> AnyWeakEntity
Converts this entity handle into a weak variant, which does not prevent it from being released.