pub struct ForegroundExecutor { /* private fields */ }Expand description
A pointer to the executor that is currently running, for spawning tasks on the main thread.
Implementations
Sourceimpl ForegroundExecutor
impl ForegroundExecutor
Sourcepub fn new(dispatcher: Arc<dyn PlatformDispatcher>) -> Self
pub fn new(dispatcher: Arc<dyn PlatformDispatcher>) -> Self
Creates a new ForegroundExecutor from the given PlatformDispatcher.
Sourcepub fn spawn<R>(&self, future: impl Future<Output = R> + 'static) -> Task<R> ⓘwhere
R: 'static,
pub fn spawn<R>(&self, future: impl Future<Output = R> + 'static) -> Task<R> ⓘwhere
R: 'static,
Enqueues the given Task to run on the main thread.
Sourcepub fn spawn_with_priority<R>(
&self,
_priority: Priority,
future: impl Future<Output = R> + 'static,
) -> Task<R> ⓘwhere
R: 'static,
pub fn spawn_with_priority<R>(
&self,
_priority: Priority,
future: impl Future<Output = R> + 'static,
) -> Task<R> ⓘwhere
R: 'static,
Enqueues the given Task to run on the main thread with the given priority.