pub struct HitboxId(/* private fields */);Expand description
An identifier for a Hitbox which also includes HitboxBehavior.
Implementations
Sourceimpl HitboxId
impl HitboxId
Sourcepub fn is_hovered(self, window: &Window) -> bool
pub fn is_hovered(self, window: &Window) -> bool
Checks if the hitbox with this ID is currently hovered. Returns false during keyboard
input modality so that keyboard navigation suppresses hover highlights. Except when handling
ScrollWheelEvent, this is typically what you want when determining whether to handle mouse
events or paint hover styles.
See Hitbox::is_hovered for details.
Sourcepub fn should_handle_scroll(self, window: &Window) -> bool
pub fn should_handle_scroll(self, window: &Window) -> bool
Checks if the hitbox with this ID contains the mouse and should handle scroll events.
Typically this should only be used when handling ScrollWheelEvent, and otherwise
is_hovered should be used. See the documentation of Hitbox::is_hovered for details about
this distinction.