pub trait PlatformGestures {
// Provided methods
fn tuning(&self) -> GestureTuning { ... }
fn native_recognizers(&self) -> GestureKinds { ... }
}Expand description
Platform gesture recognition services.
If your mobile platform supports native gesture recognition, use this to share it with GPUI.
Provided Methods
Sourcefn tuning(&self) -> GestureTuning
fn tuning(&self) -> GestureTuning
Feel constants for the portable recognizers on this platform.
Sourcefn native_recognizers(&self) -> GestureKinds
fn native_recognizers(&self) -> GestureKinds
The gesture kinds this platform recognizes natively.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".