pub trait SpringTarget: 'static {
type Output;
// Required methods
fn target(&self) -> f32;
fn resolve(&self, value: f32) -> Self::Output;
}Expand description
A value that can be targeted by a one-dimensional spring.
Implementations may project the spring coordinate into a richer output, allowing a discrete state or a path through a multidimensional value to be driven by one spring.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".