pub type ExternalDragPayloadSource = Box<dyn FnOnce(&mut Window, &mut App) -> Option<ExternalDragPayload> + 'static>;Expand description
Lazily resolves the payload handed to the platform when an internal drag is promoted to a native drag session.
Aliased Type
pub struct ExternalDragPayloadSource(/* private fields */);